@@ -7,11 +7,12 @@ pub mod exports {
     pub use bytes;
     pub use futures_util;
     pub use prost;
-    pub use tower;
     pub use tracing;
 
-    #[cfg(any(feature = "http_client", feature = "http_server"))]
+    #[cfg(feature = "_common_http")]
     pub use http;
+    #[cfg(feature = "server")]
+    pub use tower;
 }
 
 /// Common client types and functions.
@@ -45,7 +46,7 @@ pub use response::Response;
 pub type BoxError = Box<dyn std::error::Error + Send + Sync>;
 
 /// The hRPC protobuf mimetype.
-pub const HRPC_CONTENT_MIMETYPE: &[u8] = b"application/hrpc";
+pub const HRPC_CONTENT_MIMETYPE: &str = "application/hrpc";
 /// The hRPC spec version this version of `hrpc-rs` implements.
 pub const HRPC_SPEC_VERSION: &str = "1";
 
